<?php

/**
 * @file
 * Provides image fields report.
 */

/**
 * Menu callback.
 *
 * Provides image fields report.
 */
function image_styles_mapping_fields_report() {
  // Get the image styles.
  $image_styles = image_styles_mapping_get_image_styles();

  // Get the image fields.
  $image_fields = image_styles_mapping_get_image_fields();

  // Get the instances.
  $instances_info = field_info_instances();

  $header = array(
    array('data' => t('Entity'),    'field' => 'entity_type'),
    array('data' => t('Bundle'),    'field' => 'bundle'),
    array('data' => t('View mode'), 'field' => 'view_mode'),
    array('data' => t('Field'),     'field' => 'field'),
    image_styles_mapping_display_image_style_link(),
  );
  $rows = array();
  // Entities.
  foreach ($instances_info as $entity_machine_name => $bundles) {
    // Bundles.
    foreach ($bundles as $bundle => $bundle_fields) {
      // Fields.
      foreach ($bundle_fields as $field_machine_name => $field) {
        // Image field.
        if (in_array($field_machine_name, $image_fields)) {
          // View modes.
          foreach ($field['display'] as $view_mode_machine_name => $view_mode) {
            // Field enabled.
            if ($view_mode['type'] != 'hidden') {
              $view_mode_image_styles = array();
              // Use recursive search because the structure of the
              // field_formatter is unknown.
              foreach ($image_styles as $image_style_name => $image_style_label) {
                if (image_styles_mapping_search_image_styles($image_style_name, $view_mode)) {
                  $view_mode_image_styles[] = image_styles_mapping_display_image_style_link($image_style_label, $image_style_name);
                }
              }

              // Case empty.
              if (empty($view_mode_image_styles)) {
                $view_mode_image_styles[] = t('No image style used');
              }

              $view_mode_image_styles = implode(', ', $view_mode_image_styles);
              $rows[] = array(
                'entity_type' => $entity_machine_name,
                'bundle' => $bundle,
                'view_mode' => image_styles_mapping_display_view_mode_link($entity_machine_name, $bundle, $view_mode_machine_name),
                'field' => $field_machine_name,
                'image_styles' => $view_mode_image_styles,
              );
            }
          }
        }
      }
    }
  }

  $output = array();
  $output[] = array(
    '#theme' => 'html_tag',
    '#tag' => 'h2',
    '#value' => t('Image fields'),
  );

  $output[] = array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => image_styles_mapping_sort_rows($header, $rows),
    '#empty' => t('No image styles have been used in any image fields yet.'),
  );

  return $output;
}
